@@ -5,7 +5,7 @@
 ;; Author: Matthew Carter <m@ahungry.com>
 ;; Maintainer: Matthew Carter <m@ahungry.com>
 ;; URL: https://github.com/ahungry/color-theme-ahungry
-;; Version: 1.1.0
+;; Version: 1.2.0
 ;; Keywords: ahungry palette color theme emacs color-theme deftheme
 ;; Package-Requires: ((emacs "24"))
 
@@ -36,6 +36,10 @@
 
 ;;; News:
 
+;;;; Changes since 1.1.0:
+;; - New variable ahungry-theme-font-settings to avoid overriding user font sizes
+;; - Add info-mode faces
+
 ;;;; Changes since 1.0.12:
 ;; - Add erc/jabber faces to begin with
 
@@ -75,18 +79,28 @@
 (deftheme ahungry
   "Ahungry Theme")
 
+(defvar ahungry-theme-font-settings
+  '(:family "Terminus" :foundry "xos4"
+            :slant normal :weight normal
+            :height 100 :width normal)
+  "If set to nil, will avoid overriding the user font settings.
+Leave this alone to retain defaults.
+
+Default value:
+  '(:family \"Terminus\" :foundry \"xos4\"
+            :slant normal :weight normal
+            :height 100 :width normal)")
+
 (let ((mainbg (when (display-graphic-p) "#222222")));; "default")))
   (custom-theme-set-faces
    'ahungry ;; This is the theme name
    `(default ((t (:foreground "#ffffff" :background ,mainbg
-                              :family "Terminus" :foundry "xos4"
-                              :slant normal :weight normal
-                              :height 100 :width normal))))
+                              ,@ahungry-theme-font-settings))))
    '(cursor ((t (:background "#fce94f" :foreground "#ffffff"))))
    '(highlight ((t (:background "brown4" :foreground nil))))
    '(border ((t (:background "#888a85"))))
    '(fringe ((t (:background "#333333"))))
-   '(mode-line ((t (:foreground "#0022ff" :bold t :background "#77ff00"
+   '(mode-line ((t (:foreground "#0022aa" :bold t :background "#77ff00"
                                 :box (:line-width 1 :color nil :style released-button)))))
    '(mode-line-inactive ((t (:foreground "#444444" :background "#66ff33"))))
    '(mode-line-buffer-id ((t (:bold t :foreground "#ffffff" :background "#0055ff"))))
@@ -129,8 +143,6 @@
    '(isearch-lazy-highlight-face ((t (:foreground "#2e3436" :background "#ff6600"))))
    '(show-paren-match-face ((t (:background "#ff6600" :foreground "#2e3436"))))
    '(show-paren-mismatch-face ((t (:background "#999999" :foreground "#ff6600"))))
-   '(info-xref ((t (:foreground "#33ffbb"))))
-   '(info-xref-visited ((t (:foreground "#999999"))))
    '(diary ((t (:bold t :foreground "#ff0000"))))
    '(message-cited-text ((t (:foreground "#ffc800"))))
    '(gnus-cite-1 ((t (:foreground "#999999"))))
@@ -240,6 +252,16 @@
    '(jabber-chat-prompt-foreign ((t (:foreground "#ff0099"))))
    '(jabber-chat-prompt-local ((t (:foreground "#0099ff"))))
    '(jabber-rare-time-face ((t (:foreground "#666666" :bold nil :italic t))))
+   '(eshell-prompt ((t (:foreground "#0099ff"))))
+   '(info-menu-header ((t (:foreground "#0099ff" :bold t :underline t))))
+   '(info-header-xref ((t (:foreground "#0099ff"))))
+   '(info-header-node ((t (:foreground "#ff0099" :bold t :italic t))))
+   '(info-menu-star ((t (:foreground "#0099ff" :bold t))))
+   '(info-xref-visited ((t (:foreground "#999999"))))
+   '(info-xref ((t (:foreground "#0099ff"))))
+   '(info-node ((t (:foreground "#ff0099"))))
+   '(info-title-1 ((t (:foreground "yellow" :bold t))))
+   '(info-title-2 ((t (:foreground "#ff0099"))))
    )
   (custom-theme-set-variables
    'ahungry
